==> apache-parquet-1.14.1.tar.gz: apache-parquet-1.14.1/parquet-hadoop/src/main/java/org/apache/parquet/hadoop/ParquetFileReaderMetrics.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.parquet.hadoop;

public enum ParquetFileReaderMetrics {

  // metrics
  ReadTime("time spent in reading Parquet file from storage"),
  SeekTime("time spent in seek when reading Parquet file from storage"),
  ReadSize("read size when reading Parquet file from storage (MB)"),
  ReadThroughput("read throughput when reading Parquet file from storage (MB/sec)"),
  DecompressTime("time spent in block decompression"),
  DecompressSize("decompressed data size (MB)"),
  DecompressThroughput("block decompression throughput (MB/sec)");

  private final String desc;

  ParquetFileReaderMetrics(String desc) {
    this.desc = desc;
  }

  public String description() {
    return desc;
  }
}

==> apache-parquet-1.17.0.tar.gz: apache-parquet-1.17.0/parquet-hadoop/src/main/java/org/apache/parquet/hadoop/ParquetFileReaderMetrics.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.parquet.hadoop;

public enum ParquetFileReaderMetrics {

  // metrics
  ReadTime("time spent in reading Parquet file from storage"),
  SeekTime("time spent in seek when reading Parquet file from storage"),
  ReadSize("read size when reading Parquet file from storage (MB)"),
  ReadThroughput("read throughput when reading Parquet file from storage (MB/sec)"),
  DecompressTime("time spent in block decompression"),
  DecompressSize("decompressed data size (MB)"),
  DecompressThroughput("block decompression throughput (MB/sec)"),
  PagesIncluded("pages included due to column index filtering"),
  PagesSkipped("pages skipped due to column index filtering");

  private final String desc;

  ParquetFileReaderMetrics(String desc) {
    this.desc = desc;
  }

  public String description() {
    return desc;
  }
}
